import { APIResult, FluencyResult } from './lcat';

export type IeltsResult = APIResult & {
  pronunciation: {
    words: IeltsWord[];
    overall_score: number;
    expected_text: string;
    english_proficiency_scores: EnglishProficiencyScores | any;
    warnings: any;
    lowest_scoring_phonemes: LowestPhonemes[];
  };
  fluency: FluencyResult;
  metadata: {
    predicted_text: string;
    content_relevance: string;
    content_relevance_feedback: string;
  };
  vocabulary: VocabularyResult;
  grammar: GrammarResult;
  nextQuestion?: string;
};

export type IeltsWord = {
  word_text: string;
  phonemes: IeltsPhonemes[];
  word_score: number;
};

export type IeltsPhonemes = {
  ipa_label: string;
  phoneme_score: number;
};

export type LowestPhonemes = {
  ipa_label: string;
  phoneme_score: number;
};

export type EnglishProficiencyScores = {
  mock_ielts: {
    prediction: number | string;
  };
  mock_cefr: {
    prediction: number | string;
  };
  mock_pte: {
    prediction: number | string;
  };
};

export type GrammarMetrics = {
  mistake_count: number;
  grammatical_complexity: string;
  grammar_errors: Array<MistakeCorretionPosition>;
};

export interface IMistakeCorrection {
  mistake: string;
  correction: string;
}

export interface IFeedbackPosition {
  start_index: number;
  end_index: number;
}

export type MistakeCorretionPosition = IMistakeCorrection & IFeedbackPosition & { title?: string };

export type GrammarResult = {
  overall_score: number;
  english_proficiency_scores: EnglishProficiencyScores | any;
  metrics: GrammarMetrics;
  warnings?: any;
};

export type VocabularyMetrics = {
  vocabulary_complexity: string;
  idiom_details: Array<IFeedbackPosition>;
};

export type VocabularyFeedback = {
  tagged_transcript: string;
};

export type VocabularyResult = {
  overall_score: number;
  english_proficiency_scores: EnglishProficiencyScores | any;
  metrics: VocabularyMetrics;
  feedback: VocabularyFeedback;
  warnings?: any;
};

export type Metrics = {
  speech_rate?: number;
};
