import { pxToRem, remToPx, responsiveFontSizes } from '../../utils/getFontValue';

describe('pxToRem', () => {
  it('should convert 24px to 1.5rem', () => {
    expect(pxToRem(24)).toBe('1.5rem');
  });

  it('should convert 32px to 2rem', () => {
    expect(pxToRem(32)).toBe('2rem');
  });

  it('should convert 40px to 2.5rem', () => {
    expect(pxToRem(40)).toBe('2.5rem');
  });
});

describe('remToPx', () => {
  it('should convert 1.5rem to 24px', () => {
    expect(remToPx('1.5')).toBe(24);
  });

  it('should convert 2rem to 32px', () => {
    expect(remToPx('2')).toBe(32);
  });

  it('should convert 2.5rem to 40px', () => {
    expect(remToPx('2.5')).toBe(40);
  });
});

describe('responsiveFontSizes', () => {
  it('should return correct fontSize for each screen size', () => {
    expect(responsiveFontSizes({ sm: 24, md: 32, lg: 40 })).toEqual({
      '@media (min-width:600px)': {
        fontSize: '1.5rem',
      },
      '@media (min-width:900px)': {
        fontSize: '2rem',
      },
      '@media (min-width:1200px)': {
        fontSize: '2.5rem',
      },
    });
  });
});
