// @mui
import { styled } from '@mui/material/styles';
import { Card, CardProps, Typography, Box } from '@mui/material';
import Image from './Image';

interface CardStyleProps extends CardProps {
  horizontal?: boolean;
  disabled?: boolean;
}
const CardStyle = styled(Card, {
  shouldForwardProp: (prop) => prop !== 'horizontal' && prop !== 'disabled',
})<CardStyleProps>(({ horizontal, disabled }) => ({
  width: '28%',
  display: 'flex',
  flexDirection: 'column',
  alignItems: 'stretch',
  padding: '20px',
  gap: '10px',
  boxShadow: '0px -12px 24px -4px #919EAB1F',
  margin: '77px 30px',
  cursor: 'pointer',
  ...(horizontal && {
    flexDirection: 'row',
    gap: '16px',
    '& > *:first-of-type': {
      flexBasis: 'max(50%, 400px)',
    },
  }),
  ...(disabled && {
    opacity: '0.5',
    pointerEvents: 'none',
  }),
}));

const ContainerStyle = styled(Box)(() => ({
  display: 'flex',
  justifyContent: 'center',
  flexGrow: '1',
}));

const ImageStyle = styled(Image)(() => ({
  maxWidth: '100%',
  objectFit: 'cover',
}));

const TitleStyle = styled(Typography)(({ theme }) => ({
  fontSize: theme.typography.h4.fontSize,
  fontWeight: theme.typography.h4.fontWeight,
  lineHeight: '30px',
  marginBlock: '8px',
}));

type FeatureCardProps = {
  horizontal?: boolean;
  disabled?: boolean;
  title: string;
  image: string;
  handleClick?: VoidFunction;
};

export default function AccentCard(props: FeatureCardProps) {
  const { disabled, horizontal, title, image, handleClick } = props;

  return (
    <CardStyle
      disabled={disabled}
      horizontal={horizontal}
      raised={false}
      onClick={disabled ? () => {} : handleClick}
    >
      <div>
        <ImageStyle src={image} alt={`${title}`} ratio="16/9" />
      </div>
      <ContainerStyle>
        <TitleStyle>{title}</TitleStyle>
      </ContainerStyle>
    </CardStyle>
  );
}
