import Link from 'next/link';
// @mui
import { Breadcrumbs, Typography } from '@mui/material';
import NavigateNextIcon from '@mui/icons-material/NavigateNext';
import { styled } from '@mui/material/styles';

const BreadcrumbsStyle = styled(Breadcrumbs)(({ theme }) => ({
  padding: '16px clamp(20px, 8%, 90px)',
  color: theme.palette.grey[500],
  '& .MuiBreadcrumbs-li:last-of-type': {
    color: theme.palette.common.black,
  },
  borderBottom: `1px solid ${theme.palette.grey[300]}`,
}));

const linkTextStyle = {
  fontSize: 'clamp(16px, 16px, 1.7vh)',
  fontWeight: '700',
  textDecoration: 'none',
  color: 'inherit',
  '&:hover': {
    textDecoration: 'underline',
  },
};

const LinkStyle = styled(Link)(() => linkTextStyle);
const DisabledLinkStyle = styled(Typography)(() => linkTextStyle);

export default function Breadcrumb(
  breadcrumbs: Array<{
    title: string;
    location: string;
    disabled: boolean;
  }>
) {
  return (
    <BreadcrumbsStyle separator={<NavigateNextIcon fontSize="small" />} aria-label="breadcrumb">
      {breadcrumbs.map(({ title, location, disabled }) => {
        if (disabled) {
          return <DisabledLinkStyle key={title}>{title}</DisabledLinkStyle>;
        } else {
          return (
            <LinkStyle key={title} href={location}>
              {title}
            </LinkStyle>
          );
        }
      })}
    </BreadcrumbsStyle>
  );
}
