// @mui
import { styled } from '@mui/material/styles';
import { Typography, Stack } from '@mui/material';

const Root = styled(Stack)(() => ({
  flexDirection: 'row',
  gap: '2rem',
  rowGap: '1rem',
  flexWrap: 'wrap',
}));

const LegendItemContainer = styled(Stack)(() => ({
  flexDirection: 'row',
  gap: '0.75rem',
  alignItems: 'center',
  justifyContent: 'center',
}));

const Count = styled('span')(() => ({
  fontSize: '14px',
  fontWeight: '500',
  width: '24px',
  height: '24px',
  borderRadius: '100px',
  display: 'grid',
  placeItems: 'center',
}));

const LegendText = styled(Typography)(({ theme }) => ({
  fontSize: '13px',
  lineHeight: '16px',
  fontWeight: '500',
  color: theme.palette.grey[600],
}));

type DetailedTranscriptLegendProps = {
  legends: Array<{
    name: string;
    color: string;
    key: string;
    count: number;
  }>;
};

export default function DetailedTranscriptLegend(props: DetailedTranscriptLegendProps) {
  const { legends } = props;

  return (
    <Root>
      {legends.map((legend) => (
        <LegendItemContainer key={`legend-${legend.key}`}>
          <Count style={{ backgroundColor: legend.color }}>{legend.count}</Count>
          <LegendText>{legend.name}</LegendText>
        </LegendItemContainer>
      ))}
    </Root>
  );
}
