import { useMemo } from 'react';
// @mui
import { useTheme } from '@mui/material';
// component
import DetailedTranscriptLegend from './DetailedTranscriptLegend';
import { compareTexts } from 'src/utils/text';

type DetailedTranscriptLegendFluencyProps = {
  transcript: string;
  speechPhrase?: string;
};

export default function DetailedTranscriptLegendFluency(
  props: DetailedTranscriptLegendFluencyProps
) {
  const { transcript, speechPhrase = '' } = props;
  const cleanedTranscript = transcript
    .trim()
    .replace(/[.,!\?;]$/g, '')
    .replace(/<[^>]*>/g, '');
  const mistakes = useMemo(
    () => compareTexts(speechPhrase, cleanedTranscript),
    [cleanedTranscript, speechPhrase]
  );
  const theme = useTheme();
  const legends = useMemo(() => {
    const legends = [
      {
        name: 'Connectives',
        color: theme.palette.chart.violet[3],
        key: 'discourse-marker',
        count: 0,
      },
      {
        name: 'Word repetitions',
        color: theme.palette.chart.blue[3],
        key: 'word-repetition',
        count: 0,
      },
      {
        name: 'Filler word',
        color: theme.palette.chart.yellow[3],
        key: 'filler-word',
        count: 0,
      },
      {
        name: 'Pauses',
        color: theme.palette.chart.red[3],
        key: 'speech-pause',
        count: 0,
      },
    ];
    let _transcript = transcript;
    _transcript = '<text>' + _transcript + '</text>';
    const parser = new DOMParser();
    const xml = parser.parseFromString(_transcript, 'text/xml');
    if (!xml.getElementsByTagName('text').item(0)?.childNodes) return legends;

    const nodes = xml.getElementsByTagName('text').item(0)?.childNodes as NodeListOf<ChildNode>;
    let wordIdx = 0;
    for (let i = 0; i < nodes.length; i++) {
      const node = nodes[i];
      for (let j = 0; j < legends.length; j++) {
        const legend = legends[j];
        if (
          `${node.nodeName}` === legend.key &&
          (node.nodeName !== 'discourse-marker' || !mistakes[wordIdx]?.correct)
        ) {
          legend.count++;
        }
      }
      wordIdx += node.textContent?.trim()?.split(/\s/).length ?? 0;
    }
    return legends;
  }, [mistakes, theme, transcript]);

  return <DetailedTranscriptLegend legends={legends} />;
}
