import { styled } from '@mui/material/styles';
import { Typography, Popover, Stack } from '@mui/material';

const PopoverTitle = styled(Typography)(({ theme }) => ({
  color: theme.palette.grey[600],
  fontSize: '14px',
}));

type DetailedTranscriptTooltipProps = {
  open: boolean;
  anchorEl: HTMLElement | null;
  title: string;
  description: string;
  handlePopoverClose: () => void;
};

export default function DetailedTranscriptTooltip({
  open,
  anchorEl,
  title,
  description,
  handlePopoverClose,
}: DetailedTranscriptTooltipProps) {
  return (
    <Popover
      id="detailed-transcript-popover"
      sx={{ pointerEvents: 'none' }}
      open={open}
      anchorEl={anchorEl}
      anchorOrigin={{
        vertical: -8,
        horizontal: 'left',
      }}
      transformOrigin={{
        vertical: 'bottom',
        horizontal: 'left',
      }}
      onClose={handlePopoverClose}
      disableRestoreFocus
    >
      <Stack gap={1} padding="1rem">
        <PopoverTitle>{title}</PopoverTitle>
        {description && <Typography fontWeight="500">{description}</Typography>}
      </Stack>
    </Popover>
  );
}
