// hooks
import { useTranscriptPopover } from '../hooks/useTranscriptPopover';
// @mui
import { styled } from '@mui/material/styles';
import { Typography } from '@mui/material';
// components
import DetailedTranscriptTooltip from './DetailedTranscriptTooltip';
// types
import { VocabularyMetrics } from '../@types/ielts';

const Root = styled('div')(() => ({
  width: '100%',
  paddingBlock: '5px',
}));

const Marking = styled('span')(() => ({
  paddingInline: '3px',
  cursor: 'pointer',
}));

const Idiom = styled(Marking)(({ theme }) => ({
  backgroundColor: theme.palette.chart.blue[3],
}));

type DetailedVocabTranscriptProps = {
  transcript: string;
  feedback: VocabularyMetrics;
};

export default function DetailedVocabTranscript(props: DetailedVocabTranscriptProps) {
  const { transcript, feedback } = props;
  const { idiom_details: idioms = [] } = feedback;
  const { anchorEl, open, title, description, handlePopoverOpen, handlePopoverClose } =
    useTranscriptPopover();

  const composeTranscript = () => {
    const transcriptArr = [];
    let start = 0;
    for (let i = 0; i < idioms.length; i++) {
      const idiom = idioms[i];
      const end = idiom.start_index;
      transcriptArr.push(transcript.substring(start, end));
      transcriptArr.push(
        <Idiom
          key={`transcript-vocab-${i}`}
          onMouseEnter={(event) => handlePopoverOpen(event, 'Idiom', '')}
          onMouseLeave={handlePopoverClose}
        >
          {transcript.substring(end, idiom.end_index)}
        </Idiom>
      );
      start = idiom.end_index;
    }
    if (start < transcript.length) transcriptArr.push(transcript.substring(start));

    return transcriptArr;
  };

  return (
    <Root>
      <Typography>{composeTranscript()}</Typography>
      <DetailedTranscriptTooltip
        open={open}
        anchorEl={anchorEl}
        title={title}
        description={description}
        handlePopoverClose={handlePopoverClose}
      />
    </Root>
  );
}
