import { Stack, SxProps, Typography, alpha, styled, useTheme } from '@mui/material';

const USER_AVA = '/icons/ava-user.png';
const BOT_AVA = '/icons/ava-bot.png';

const ImageStyle = styled('img')(() => ({
  width: '32px',
  aspectRatio: '1/1',
}));

type DialogueProps = {
  messages: string[];
  onMessageClick: (question: number) => void;
  selectedQuestion?: number;
  sx?: SxProps;
};

export default function Dialogue(props: DialogueProps) {
  const { messages, sx, onMessageClick, selectedQuestion } = props;
  const theme = useTheme();

  return (
    <Stack width="100%" sx={sx}>
      {messages.map((message, index) => (
        <Stack
          flexDirection="row"
          flexWrap="nowrap"
          alignItems="center"
          justifyContent="flex-start"
          key={`dialogue-ms-${index}`}
          gap="1rem"
          padding="1.5rem"
          sx={{
            backgroundColor:
              index % 2 === 0 ? 'transparent' : alpha(theme.palette.primary.main, 0.05),
            cursor: 'pointer',
          }}
          onClick={() => onMessageClick(Math.floor(index / 2))}
        >
          {index % 2 === 0 ? (
            <ImageStyle src={BOT_AVA} alt="bot avatar" />
          ) : (
            <ImageStyle src={USER_AVA} alt="user avatar" />
          )}
          <Typography
            fontWeight={700}
            lineHeight={'25px'}
            sx={{
              opacity: selectedQuestion === Math.floor(index / 2) ? 1 : 0.5,
            }}
          >
            {message}
          </Typography>
        </Stack>
      ))}
    </Stack>
  );
}
