import { useState } from 'react';
// mui
import { Box, Stack, Tab, Tabs, styled } from '@mui/material';

const TabContainer = styled(Box)(({ theme }) => ({
  borderBottom: '2px solid ' + theme.palette.divider,
  alignSelf: 'center',
  display: 'flex',
  justifyContent: 'center',
  width: '100%',
  '& .MuiTabs-indicator': {
    height: '3px',
  },
  '& .MuiTabs-root': {
    marginBottom: '-2px',
  },
  '& .MuiTabs-flexContainer': {
    gap: '1rem',
  },
}));

const TabButton = styled(Tab)(({ theme }) => ({
  fontSize: '1rem',
  color: theme.palette.grey[500],
}));

const FeedbackCardContainer = styled(Box)(() => ({
  display: 'flex',
  flexWrap: 'wrap',
  justifyContent: 'center',
}));

function a11yProps(index: number) {
  return {
    id: `scrollable-auto-tab-${index}`,
    'aria-controls': `scrollable-auto-tabpanel-${index}`,
  };
}

type FeedbackTabsSectionProps = {
  feedbackTabs: Array<{
    title: string;
    key: string;
  }>;
  feedbackSections: Record<string, JSX.Element>;
};

export default function FeedbackTabsSection(props: FeedbackTabsSectionProps) {
  const [feedbackTab, setFeedbackTab] = useState(0);
  const { feedbackTabs, feedbackSections } = props;

  return (
    <Stack gap={4}>
      <TabContainer>
        <Tabs
          value={feedbackTab}
          onChange={(_event, newValue) => setFeedbackTab(newValue)}
          aria-label="feedback-tabs"
          variant="scrollable"
          scrollButtons
          allowScrollButtonsMobile
        >
          {feedbackTabs.map((tab, index) => (
            <TabButton key={index} label={tab.title} {...a11yProps(index)} />
          ))}
        </Tabs>
      </TabContainer>
      <FeedbackCardContainer>
        {feedbackSections[feedbackTabs[feedbackTab].key as keyof typeof feedbackSections]}
      </FeedbackCardContainer>
    </Stack>
  );
}
