// @mui
import { styled, alpha } from '@mui/material/styles';
import { Box, Typography, Button, Tab, Tabs } from '@mui/material';
// components
import Page from 'src/components/Page';
import { FinalReportProps, SampleResult } from 'src/@types/final-report';
import { setColor } from 'src/utils/getScoreColor';
import { useRouter } from 'next/router';
import { useState } from 'react';
import ReportChart from './ReportChart';

const RootStyle = styled(Box)(({ theme }) => ({
  minHeight: 'calc(100vh - 130px)',
  width: '100%',
  display: 'flex',
  flexDirection: 'column',
  alignItems: 'center',
  backgroundColor: alpha(theme.palette.primary.light, 0.1),
  '& .container': {
    backgroundColor: '#FFF',
    borderRadius: '20px',
    width: '80%',
    maxWidth: '1200px',
    height: 'fit-content',
    margin: '4vh',
    '& .buttonSection': {
      padding: '0px 30px 40px',
      '& .solidLine': {
        borderBlockStart: '1px solid #3BA09E',
        textAlign: 'end',
      },
      '& .solidLineAdvanced': {
        borderBlockStart: '1px solid #3BA09E',
        [theme.breakpoints.up('md')]: {
          display: 'flex',
          justifyContent: 'flex-end',
        },
        [theme.breakpoints.down('md')]: {
          textAlign: 'center',
        },
      },
    },
  },
}));

const SectionStyle = styled(Box)(() => ({
  padding: '60px 84px 0px',
  '& .sampleResult': {
    padding: '0px 40px',
  },
  '& .lowestPhonmes': {
    display: 'flex',
    padding: '20px 40px 60px',
  },
  '& .sectionTitle': {
    fontWeight: 700,
    fontSize: 'clamp(20px, 20px, 1.7vh)',
  },
}));

const AverageScoreStyle = styled(Typography)(() => ({
  fontWeight: 500,
  fontSize: 'clamp(20px, 20px, 1.7vh)',
  justifyContent: 'center',
  alignItems: 'center',
  padding: '20px 0px',
  display: 'flex',
  '& .averageScore': {
    fontWeight: 700,
    fontSize: 'clamp(28px, 28px, 2vh)',
  },
}));

const SampleResultStyle = styled(Box)(() => ({
  borderBottom: '1px solid rgba(145, 158, 171, 0.1)',
  padding: '10px 0px',
  display: 'flex',
  justifyContent: 'space-between',
  '& .sampleQuestion': {
    fontWeight: 700,
    fontSize: 'clamp(16px, 16px, 1.5vh)',
    display: 'flex',
    '& .question': {
      fontWeight: 500,
      fontSize: 'clamp(16px, 16px, 1.5vh)',
    },
  },
  '& .sampleScore': {
    fontWeight: 500,
    fontSize: 'clamp(16px, 16px, 1.5vh)',
    display: 'flex',
    '& .score': {
      fontSize: 'clamp(16px, 16px, 1.5vh)',
    },
  },
}));

// const PhonemeStyle = styled(Box)(() => ({
//   width: '33%',
//   textAlign: 'center',
//   margin: '0px 10px',
//   '& .phoneme': {
//     fontSize: 'clamp(48px, 48px, 3vh)',
//     fontWeight: 700,
//     lineHeight: '1.3',
//   },
//   '& .word': {
//     fontSize: '18px',
//     fontWeight: 500,
//     marginBottom: '15px',
//   },
//   '& .phonemeScore': {
//     fontWeight: 700,
//     fontSize: 'clamp(16px, 16px, 1.5vh)',
//     display: 'flex',
//     justifyContent: 'center',
//     '& .score': {
//       fontWeight: 700,
//       fontSize: 'clamp(16px, 16px, 1.5vh)',
//     },
//   },
// }));

const TabContainer = styled(Box)(() => ({
  alignSelf: 'center',
  width: '36vw',
  borderRadius: '100px',
  backgroundColor: '#E6E8EC',
}));

const TabButton = styled(Tab)(({ theme }) => ({
  width: '12vw',
  borderRadius: '100px',
  '& .Mui-selected': {
    backgroundColor: theme.palette.primary.main,
    color: '#FFFFFF !important',
  },
}));

const ButtonStyle = styled(Button)(({ theme }) => ({
  padding: '16px 100px',
  fontSize: '16px',
  fontWeight: '700',
  lineHeight: '22px',
  borderRadius: '4px',
  alignSelf: 'flex-end',
  margin: '32px 20px 0px',
  '&:hover': {
    backgroundColor: theme.palette.primary.main,
  },
}));

const ReturnButtonStyle = styled(Button)(() => ({
  padding: '16px 60px',
  fontSize: '16px',
  fontWeight: '700',
  lineHeight: '22px',
  borderRadius: '4px',
  marginTop: '32px',
  alignSelf: 'flex-end',
}));

const ReportContainer = styled(Box)(() => ({
  paddingBlock: '20px 25px',
  display: 'flex',
  flexDirection: 'column',
  gap: '3em',
  width: '100%',
}));

function a11yProps(index: number) {
  return {
    id: `scrollable-auto-tab-${index}`,
    'aria-controls': `scrollable-auto-tabpanel-${index}`,
  };
}

function ieltsToCerf(ielstScore: number) {
  if (ielstScore <= 2) {
    return 1;
  } else if (ielstScore <= 4) {
    return 2;
  } else if (ielstScore <= 5.5) {
    return 3;
  } else if (ielstScore <= 7) {
    return 4;
  } else if (ielstScore <= 8.5) {
    return 5;
  } else {
    return 6;
  }
}

export default function FinalReport({
  handleNextQuestion,
  level,
  sampleResult,
  // phonesResult,
  ieltsResult,
  pteResult,
}: FinalReportProps) {
  const router = useRouter();
  const [tab, setTab] = useState(0);
  const [test, setTest] = useState('ielts');

  let sum = 0;
  sampleResult.forEach((question: SampleResult) => {
    sum += question.score;
  });
  const averageScore = Math.round(sum / sampleResult.length);

  let fluencyIelts = 0;
  let pronunciationIelts = 0;
  let overallIelts = 0;
  ieltsResult.forEach((question) => {
    fluencyIelts += question.fluency;
    pronunciationIelts += question.pronunciation;
    overallIelts += question.overall;
  });
  const averageFluencyIelts = Math.round(fluencyIelts / ieltsResult.length);
  const averagePronunciationIelts = Math.round(pronunciationIelts / ieltsResult.length);
  const averageOverallIelts = Math.round(overallIelts / ieltsResult.length);

  let fluencyPte = 0;
  let pronunciationPte = 0;
  let overallPte = 0;
  pteResult.forEach((question) => {
    fluencyPte += Number(question.fluency);
    pronunciationPte += Number(question.pronunciation);
    overallPte += Number(question.overall);
  });

  const averageFluencyPte = Math.round(fluencyPte / pteResult.length);
  const averagePronunciationPte = Math.round(pronunciationPte / pteResult.length);
  const averageOverallPte = Math.round(overallPte / pteResult.length);

  const avergaeFluencyCerf = ieltsToCerf(averageFluencyIelts);
  const avergaePronunciationCerf = ieltsToCerf(averagePronunciationIelts);
  const avergaeOverallCerf = ieltsToCerf(averageOverallIelts);

  const skillResult = {
    fluency:
      test === 'ielts'
        ? averageFluencyIelts
        : test === 'pte'
          ? averageFluencyPte
          : avergaeFluencyCerf,
    pronunciation:
      test === 'ielts'
        ? averagePronunciationIelts
        : test === 'pte'
          ? averagePronunciationPte
          : avergaePronunciationCerf,
  };

  // const averageScorePhonesList = [] as averageScorePhones[];
  // for (const [key, value] of Object.entries(phonesResult)) {
  //   averageScorePhonesList.push({
  //     label: key,
  //     word: value.word,
  //     average_score: Math.round(value.total_score / value.occurence),
  //   });
  // }
  // averageScorePhonesList.sort((a, b) => a.average_score - b.average_score);

  // const lowestPhonemes: averageScorePhones[] = [];
  // for (let i = 0; i < 3; i++) {
  //   lowestPhonemes.push(averageScorePhonesList[i]);
  // }

  const handleReturnPronunciation = () => {
    window.localStorage.clear();
    router.push('/scripted');
  };

  function handleChange(event: any, newValue: number) {
    setTab(newValue);
    switch (newValue) {
      case 0:
        setTest('ielts');
        break;
      case 1:
        setTest('pte');
        break;
      case 2:
        setTest('cefr');
        break;
      default:
        break;
    }
  }

  const setButton = () => {
    if (level === 'advanced' || level === 'custom') {
      return (
        <Box className="solidLine">
          <ButtonStyle onClick={handleNextQuestion}>Return to homepage</ButtonStyle>
        </Box>
      );
    } else {
      return (
        <Box className="solidLineAdvanced">
          <ReturnButtonStyle onClick={handleReturnPronunciation} variant="outlined">
            Return to homepage
          </ReturnButtonStyle>
          <ButtonStyle onClick={handleNextQuestion} variant="contained">
            Next Level
          </ButtonStyle>
        </Box>
      );
    }
  };

  return (
    <Page title="Final Report">
      <RootStyle>
        <Box className="container">
          <SectionStyle>
            <Typography className="sectionTitle">1. Average Score</Typography>
            <AverageScoreStyle sx={{ color: setColor(averageScore) }}>
              Average Score:&nbsp;
              <Typography className="averageScore">{averageScore}%</Typography>
            </AverageScoreStyle>
            <Box className="sampleResult">
              {sampleResult &&
                sampleResult.map((sample, i) => (
                  <SampleResultStyle key={i}>
                    <Typography className="sampleQuestion">
                      Sample {i + 1}:&nbsp;
                      <Typography className="question">{sample.text}</Typography>
                    </Typography>
                    <Typography className="sampleScore" sx={{ color: setColor(sample.score) }}>
                      Score:&nbsp;<Typography className="score">{sample.score}%</Typography>
                    </Typography>
                  </SampleResultStyle>
                ))}
            </Box>
          </SectionStyle>
          {/* <SectionStyle>
            <Typography className="sectionTitle">2. Top 3 lowest scoring phonemes</Typography>
            <Box className="lowestPhonmes">
              {lowestPhonemes &&
                lowestPhonemes.map((phoneme) => (
                  <PhonemeStyle key={phoneme.label}>
                    <Typography className="phoneme">/{phoneme.label}/</Typography>
                    <Typography className="word">({phoneme.word})</Typography>
                    <Typography
                      className="phonemeScore"
                      sx={{ color: setColor(phoneme.average_score) }}
                    >
                      Score:&nbsp;
                      <Typography className="score">{phoneme.average_score}%</Typography>
                    </Typography>
                  </PhonemeStyle>
                ))}
            </Box>
          </SectionStyle> */}
          <SectionStyle>
            <Typography className="sectionTitle">2. Report Score</Typography>
            <ReportContainer>
              <TabContainer>
                <Tabs
                  value={tab}
                  onChange={handleChange}
                  aria-label="tabs"
                  TabIndicatorProps={{
                    style: { display: 'none' },
                  }}
                >
                  <TabButton label="Mock IELTS" {...a11yProps(0)} />
                  <TabButton label="PTE" {...a11yProps(1)} />
                  <TabButton label="CEFR" {...a11yProps(2)} />
                </Tabs>
              </TabContainer>
              <ReportChart
                overall={
                  test === 'ielts'
                    ? averageOverallIelts
                    : test === 'pte'
                      ? averageOverallPte
                      : avergaeOverallCerf
                }
                skillResults={skillResult}
                test={test}
                unscripted={false}
              />
            </ReportContainer>
          </SectionStyle>
          <Box className="buttonSection">{setButton()}</Box>
        </Box>
      </RootStyle>
    </Page>
  );
}
