import { v4 as uuidv4 } from 'uuid';
//mui
import { Typography, Box, Stack } from '@mui/material';
import { styled, alpha } from '@mui/material/styles';
// type
import { IeltsResult } from '../@types/ielts';
// components
import PronunciationResult from './PronunciationResult';
import FeedbackTabsSection from './FeedbackTabsSection';
import FeedbackSection from './FeedbackSection';
import IeltsResultTabs from './IeltsResultTabs';
// utils
import parseFeedback from 'src/utils/parseFeedback';
import { useMemo } from 'react';

export const ReportContainer = styled(Stack)(() => ({
  borderBlock: '1px dashed #599F44',
  paddingBlock: '60px 3rem',
  flexDirection: 'column',
  justifyContent: 'center',
  gap: '3rem',
  width: '100%',
}));

export const ScoreContainer = styled('div')(({ theme }) => ({
  width: 'fit-content',
  margin: '18px auto',
  backgroundColor: theme.palette.common.white,
  boxShadow: `0 0 0 20px ${theme.palette.common.white}`,
  position: 'relative',
  bottom: '-40px',
}));

export const ScoreStyle = styled(Typography)(({ theme }) => ({
  color: theme.palette.primary.main,
  backgroundColor: alpha(theme.palette.primary.light, 0.3),
  fontWeight: 500,
  fontSize: '16px',
  lineHeight: '22px',
  display: 'flex',
  alignItems: 'center',
  padding: '8px 20px',
  borderRadius: '200px',
}));

const FEEDBACK_TABS = [
  {
    title: 'Content relevance',
    key: 'content',
  },
  {
    title: 'Pronunciation',
    key: 'pronunciation',
  },
  {
    title: 'Fluency',
    key: 'fluency',
  },
  {
    title: 'Grammar',
    key: 'grammar',
  },
  {
    title: 'Vocabulary',
    key: 'vocabulary',
  },
];

type IeltsResultSectionProps = {
  result: IeltsResult;
};

export default function IeltsResultSection(props: IeltsResultSectionProps) {
  const result = props.result;
  const { metaData, fluencyFeedback, grammarFeedback, vocabularyFeedback } = parseFeedback(result);

  const feedbackSections = useMemo(() => {
    const id = uuidv4();
    return {
      content: <FeedbackSection uniqueId={`${id}-content`} data={metaData} />,
      pronunciation: (
        <PronunciationResult uniqueId={`${id}-pronunciation`} words={result.pronunciation.words} />
      ),
      fluency: <FeedbackSection uniqueId={`${id}-fluency`} data={fluencyFeedback} />,
      grammar: <FeedbackSection uniqueId={`${id}-grammar`} data={grammarFeedback} />,
      vocabulary: <FeedbackSection uniqueId={`${id}-vocabulary`} data={vocabularyFeedback} />,
    };
  }, [result, metaData, fluencyFeedback, grammarFeedback, vocabularyFeedback]);

  return (
    <Box sx={{ width: '100%' }}>
      <ScoreContainer>
        <ScoreStyle>Speaking Report</ScoreStyle>
      </ScoreContainer>
      <ReportContainer>
        <IeltsResultTabs result={result} />
        <FeedbackTabsSection feedbackTabs={FEEDBACK_TABS} feedbackSections={feedbackSections} />
      </ReportContainer>
    </Box>
  );
}
