import { Box, Tab, Tabs, styled } from '@mui/material';
import { useState } from 'react';
import { IeltsResult } from 'src/@types/ielts';
import ReportChart from './ReportChart';
import { CEFR_TO_NUMBER, TESTS } from 'src/utils/scoreUtils';
import { LCWritingResult } from 'src/@types/writing';

const TabContainer = styled(Box)(() => ({
  alignSelf: 'center',
  width: 'clamp(280px, 70%, 500px)',
  borderRadius: '100px',
  backgroundColor: '#E6E8EC',
  display: 'flex',
  '& .MuiTabs-root': {
    width: '100%',
  },
  fontSize: '16px',
  fontWeight: '500',
  lineHeight: '24px',
}));

const TabButton = styled(Tab)(({ theme }) => ({
  flex: '1 1 100%',
  fontSize: '0.9rem',
  borderRadius: '100px',
  color: '#777E90',
  '&.Mui-selected': {
    backgroundColor: theme.palette.primary.main,
    color: '#FFFFFF !important',
  },
}));

const a11yProps = (index: number) => ({
  id: `scrollable-auto-tab-${index}`,
  'aria-controls': `scrollable-auto-tabpanel-${index}`,
});

interface IeltsResultTabsProps {
  result: IeltsResult | LCWritingResult;
}

export default function IeltsResultTabs({ result }: IeltsResultTabsProps) {
  const [tab, setTab] = useState(0);
  const [test, setTest] = useState('ielts');
  const skillResult = {
    ...(!('writing' in result) && {
      pronunciation: result.pronunciation.english_proficiency_scores[`mock_${test}`].prediction,
      fluency: result.fluency.english_proficiency_scores[`mock_${test}`].prediction,
    }),
    vocabulary: result.vocabulary.english_proficiency_scores[`mock_${test}`].prediction,
    grammar: result.grammar.english_proficiency_scores[`mock_${test}`].prediction,
  };

  const handleTabChange = (_event: any, newValue: number) => {
    setTab(newValue);
    setTest(TESTS[newValue]);
  };

  return (
    <>
      <TabContainer>
        <Tabs
          value={tab}
          onChange={handleTabChange}
          aria-label="basic tabs example"
          TabIndicatorProps={{
            style: { display: 'none' },
          }}
        >
          <TabButton label="Mock IELTS" {...a11yProps(0)} />
          <TabButton label="PTE" {...a11yProps(1)} />
          <TabButton label="CEFR" {...a11yProps(2)} />
        </Tabs>
      </TabContainer>
      <ReportChart
        overall={
          result.overall.english_proficiency_scores
            ? test === 'cefr'
              ? CEFR_TO_NUMBER[
                  result.overall.english_proficiency_scores[`mock_${test}`]
                    .prediction as keyof typeof CEFR_TO_NUMBER
                ]
              : result.overall.english_proficiency_scores[`mock_${test}`].prediction
            : 0
        }
        skillResults={
          test === 'cefr'
            ? Object.fromEntries(
                Object.entries(skillResult).map(([key, value]) => [
                  key,
                  CEFR_TO_NUMBER[value as keyof typeof CEFR_TO_NUMBER],
                ])
              )
            : skillResult
        }
        test={test}
        unscripted={true}
      />
    </>
  );
}
