//mui
import { Typography, Box, Stack } from '@mui/material';
import { styled } from '@mui/material/styles';
import { IeltsWord } from 'src/@types/ielts';
import { setColor } from 'src/utils/getScoreColor';
//type
import { LcatWord } from '../@types/lcat';

const WordContainerStyle = styled(Box)(() => ({
  borderRadius: '4px',
  border: '1px solid rgba(145, 158, 171, 0.1)',
  margin: '0px 20px 20px 0px',
  textAlign: 'center',
  backgroundColor: 'rgba(108, 198, 196, 0.05)',
  padding: '14px 10px 10px 10px',
}));

const WordStyle = styled(Typography)(() => ({
  color: '#3BA09E',
  fontWeight: 700,
  marginBottom: '20px',
}));

const PhoneContainerStyle = styled(Box)(() => ({
  display: 'flex',
}));

const PhoneStyle = styled(Box)(() => ({
  padding: '5px',
  textAlign: 'center',
}));

const PhoneLabelStyle = styled(Typography)(() => ({
  padding: '5px 10px',
  textAlign: 'center',
  color: '#FFF',
  fontWeight: 700,
}));

const PhoneScoreStyle = styled(Typography)(() => ({
  textAlign: 'center',
  fontWeight: 700,
  fontSize: '12px',
  lineHeight: '22px',
  paddingTop: '5px',
}));

type ResultSectionProps = {
  uniqueId?: string;
  words: LcatWord[] | IeltsWord[];
};

function PronunciationResult(props: ResultSectionProps) {
  const { uniqueId, words } = props;

  return (
    <Stack sx={{ width: '100%' }} direction="row" gap={2} flexWrap="wrap" justifyContent="center">
      {words.map((word) => (
        <WordContainerStyle key={`${uniqueId ?? ''}-${word.word_text}`}>
          <WordStyle>{word.word_text.toLowerCase()}</WordStyle>
          <PhoneContainerStyle>
            {word.phonemes.map((phone) => (
              <PhoneStyle key={`${uniqueId ?? ''}-${word.word_text}-${phone.ipa_label}`}>
                <PhoneLabelStyle sx={{ backgroundColor: setColor(phone.phoneme_score) }}>
                  {phone.ipa_label}
                </PhoneLabelStyle>
                <PhoneScoreStyle>{phone.phoneme_score}%</PhoneScoreStyle>
              </PhoneStyle>
            ))}
          </PhoneContainerStyle>
        </WordContainerStyle>
      ))}
    </Stack>
  );
}

export default PronunciationResult;
