// @mui
import { styled } from '@mui/material/styles';
import {
  Typography,
  Stack,
  Box,
  Button,
  CircularProgress,
  circularProgressClasses,
} from '@mui/material';
import { PauseCircle, Mic } from '@mui/icons-material';
// components
import Record from '../components/Record';

const RecordingSectionStyle = styled(Stack)(() => ({
  gap: '30px',
  alignItems: 'center',
  justifyContent: 'center',
  width: '100%',
  maxWidth: '775px',
}));

const RecordingButtonStyle = styled(Button)(() => ({
  color: '#3BA09E',
  backgroundColor: 'rgba(108, 198, 196, 0.3)',
  borderRadius: '100%',
  height: '160px',
  width: '160px',
  marginBottom: '12px',
}));

const DurationTextStyle = styled(Typography)(() => ({
  fontWeight: 600,
  fontSize: '16px',
  lineHeight: '30px',
  color: '#3BA09E',
}));

const DescriptionStyle = styled(Typography)(() => ({
  fontWeight: 500,
  fontSize: '16px',
  lineHeight: '24px',
  color: '#919EAB',
  cursor: 'pointer',
  textAlign: 'center',
}));

const CircularProgressStyle = styled(CircularProgress)(() => ({
  position: 'absolute',
  top: '-10px',
  left: '-10px',
  [`& .${circularProgressClasses.circle}`]: {
    strokeLinecap: 'round',
  },
}));

type RecordingSectionProps = {
  recording: boolean;
  duration: number;
  maxDuration: number;
  preDescription?: string;
  handleRecording: VoidFunction;
  handleStop: (blobFile: any) => void;
};

export default function RecordingSection(props: RecordingSectionProps) {
  const { recording, duration, maxDuration, handleRecording, handleStop } = props;
  const preDescription = props.preDescription ? `${props.preDescription}. ` : '';

  return (
    <RecordingSectionStyle>
      <Box sx={{ position: 'relative' }}>
        {recording && (
          <CircularProgressStyle
            color="primary"
            size={180}
            thickness={1.5}
            variant="determinate"
            value={Math.min((duration * 100) / maxDuration, 100)}
          />
        )}
        <RecordingButtonStyle onClick={handleRecording}>
          {recording ? (
            <PauseCircle sx={{ height: '100px', width: '100px' }} />
          ) : (
            <Mic sx={{ height: '100px', width: '100px' }} />
          )}
        </RecordingButtonStyle>
      </Box>
      {recording && (
        <DurationTextStyle>{`Time elapsed: ${Math.floor(duration)} seconds`}</DurationTextStyle>
      )}
      <DescriptionStyle>
        {`${preDescription}Click the microphone button above to start recording, pause for a moment and then start speaking. Once you have finished your attempt, click the stop button and your audio will be submitted.`}
      </DescriptionStyle>
      <Record recording={recording} onStop={handleStop} />
    </RecordingSectionStyle>
  );
}
