import { useState, ChangeEvent } from 'react';
import useInterval from '../hooks/useInterval';
// @mui
import { styled } from '@mui/material/styles';
import { Typography, Stack, Button, TextField, alpha } from '@mui/material';
import {
  VolumeUp,
  // HeadsetMic,
} from '@mui/icons-material';
// component
import RecordingSection from './RecordingSection';

const RootStyle = styled(Stack)(() => ({
  width: '100%',
  borderRadius: '10px',
  alignItems: 'center',
  gap: '24px',
  '& div:nth-child(3)': {
    marginTop: '20px',
  },
}));

const TitleStyle = styled(Typography)(({ theme }) => ({
  fontSize: theme.typography.h2.fontSize,
  fontWeight: theme.typography.h2.fontWeight,
  lineHeight: '48px',
  textAlign: 'center',
}));

const TextFieldStyle = styled(TextField)(() => ({
  marginBlock: '20px 10px',
  width: '80%',
}));

const ButtonStyle = styled(Button)(({ theme }) => ({
  padding: '12px 30px',
  fontSize: '16px',
  fontWeight: '500',
  lineHeight: '24px',
  color: theme.palette.common.black,
  borderRadius: '4px',
}));

const ButtonContainedStyle = styled(ButtonStyle)(({ theme }) => ({
  backgroundColor: theme.palette.secondary.main,
  '&:hover': {
    backgroundColor: alpha(theme.palette.secondary.main, 0.7),
  },
}));

// const ButtonOutlineStyle = styled(ButtonStyle)(({ theme }) => ({
//   border: `1px solid ${theme.palette.secondary.main}`,
// }));

const maxDuration = 44;

type TestSectionProps = {
  text: string;
  audioUrl: string;
  blobUrl: string;
  customText: string;
  handleCustomTextChange: (event: ChangeEvent<HTMLInputElement | HTMLTextAreaElement>) => void;
  handleSubmit: (blobFile: any) => void;
};

export default function TestSection(props: TestSectionProps) {
  const {
    text,
    customText,
    handleCustomTextChange,
    // audioUrl,
    blobUrl,
    handleSubmit,
  } = props;
  // TODO: Uncomment to activate play audio (e.g read question out loud) functionality
  // const [audio] = useState(new Audio(audioUrl));
  // const [playingAudio, setPlayingAudio] = useState(false);
  const [playingRecording, setPlayingRecording] = useState(false);
  const [recording, setRecording] = useState(false);
  const [duration, setDuration] = useState(0);

  // useEffect(() => {
  //   audio.addEventListener('ended', () => setPlayingAudio(false));
  //   return () => {
  //     audio.removeEventListener('ended', () => setPlayingAudio(false));
  //     audio.pause();
  //   };
  // }, [audio]);

  useInterval(
    () => {
      setDuration(duration + 0.2);
      if (duration >= maxDuration) setRecording(false);
    },
    recording ? 200 : null
  );

  useInterval(
    () => {
      setPlayingRecording(false);
    },
    playingRecording ? (duration + 1) * 1000 : null
  );

  const handleRecording = () => {
    if (!recording) setDuration(0);
    setRecording(!recording);
  };

  // const handlePlayAudio = () => {
  //   audio.play();
  //   setPlayingAudio(true);
  // }

  const handlePlayRecording = async () => {
    try {
      setPlayingRecording(true);
      const recordingAudio = new Audio(blobUrl);
      await recordingAudio.play();
    } catch (error) {
      console.error(error);
    }
  };

  return (
    <RootStyle>
      {text ? (
        <TitleStyle>{text}</TitleStyle>
      ) : (
        <TextFieldStyle
          multiline
          placeholder="Type Your Question ...."
          value={customText}
          onChange={handleCustomTextChange}
        />
      )}
      <Stack direction="row" gap="24px">
        {/* <ButtonContainedStyle
          variant="contained"
          disableElevation
          disabled
          startIcon={<VolumeUp />}
          onClick={handlePlayAudio}
        >
          Play Audio (To be updated later)
        </ButtonContainedStyle> */}
        <ButtonContainedStyle
          variant="contained"
          disableElevation
          startIcon={<VolumeUp />}
          disabled={!blobUrl || playingRecording}
          onClick={handlePlayRecording}
        >
          Play Recording
        </ButtonContainedStyle>
      </Stack>
      <RecordingSection
        recording={recording}
        duration={duration}
        preDescription={`You need to speak no more than ${maxDuration + 1} seconds`}
        maxDuration={maxDuration}
        handleRecording={handleRecording}
        handleStop={handleSubmit}
      />
    </RootStyle>
  );
}
