import dynamic from 'next/dynamic';
//mui
import { Box, Stack, Typography } from '@mui/material';
import { styled, alpha } from '@mui/material/styles';
// type
import { IeltsResult } from '../@types/ielts';
// components
import FeedbackTabsSection from './FeedbackTabsSection';
import FeedbackSection from './FeedbackSection';
import IeltsResultTabs from './IeltsResultTabs';
import {
  ReportContainer,
  ScoreContainer as _ScoreContainer,
  ScoreStyle,
} from './IeltsResultSection';
// utils
import parseFeedback, { writingResultToIelts } from 'src/utils/parseFeedback';
import { useMemo } from 'react';
import { LCWritingResult } from 'src/@types/writing';
const DynamicReactJson = dynamic(import('react-json-view'), { ssr: false });

const ScoreContainer = styled(_ScoreContainer)(() => ({
  marginBlock: 0,
  bottom: '-20px',
}));

const ResultDetailContainerStyle = styled(Box)(({ theme }) => ({
  width: '100%',
  borderRadius: '8px',
  padding: '1.25rem 1.5rem',
  backgroundColor: alpha(theme.palette.primary.light, 0.05),
}));

const FEEDBACK_TABS = [
  {
    title: 'Relevance',
    key: 'relevance',
  },
  {
    title: 'Grammar',
    key: 'grammar',
  },
  {
    title: 'Vocabulary',
    key: 'vocabulary',
  },
];

type WritingResultSectionProps = {
  result: LCWritingResult;
};

export default function WritingResultSection({ result }: WritingResultSectionProps) {
  const convertedIeltsResult = writingResultToIelts(result);
  const { metaData, grammarFeedback, vocabularyFeedback } = parseFeedback(convertedIeltsResult);
  const correctedText = (() => {
    const { text } = result;
    let correctedText = '';
    let start = 0;
    convertedIeltsResult.grammar.metrics.grammar_errors.forEach((error, idx) => {
      const end = error.start_index;
      correctedText += text.substring(start, end) + error.correction;
      start = error.end_index;
    });
    if (start < text.length) correctedText += text.substring(start);

    return correctedText;
  })();

  const feedbackSections = useMemo(
    () => ({
      ...(result.relevance && { relevance: <FeedbackSection data={[metaData[1]]} /> }),
      grammar: <FeedbackSection data={[grammarFeedback[1]]} />,
      vocabulary: <FeedbackSection data={vocabularyFeedback} />,
    }),
    [grammarFeedback, metaData, result.relevance, vocabularyFeedback]
  );

  return (
    <Stack width="100%" gap={6}>
      <div>
        <ScoreContainer>
          <ScoreStyle>Writing Report</ScoreStyle>
        </ScoreContainer>
        <ReportContainer>
          <IeltsResultTabs result={result as unknown as IeltsResult} />
          <FeedbackTabsSection
            feedbackTabs={FEEDBACK_TABS.slice(result.relevance ? 0 : 1, FEEDBACK_TABS.length)}
            feedbackSections={feedbackSections}
          />
        </ReportContainer>
      </div>

      <Stack gap={3}>
        <Typography variant="h4">Writing Errors</Typography>
        <ResultDetailContainerStyle>{grammarFeedback[0].children}</ResultDetailContainerStyle>
      </Stack>

      <Stack gap={3}>
        <Typography variant="h4">Corrected Text</Typography>
        <ResultDetailContainerStyle>{correctedText}</ResultDetailContainerStyle>
      </Stack>

      <Stack gap={3}>
        <Typography variant="h4">API Output</Typography>
        <ResultDetailContainerStyle>
          <DynamicReactJson src={result} collapsed={0} />
        </ResultDetailContainerStyle>
      </Stack>
    </Stack>
  );
}
