import { ReactNode, useEffect } from 'react';
// @mui
import { styled, useTheme } from '@mui/material/styles';
import { Box, alpha } from '@mui/material';
// components
import Header from './Header';
import Footer from './Footer';
import GoogleAnalytics from 'src/components/GoogleAnalytics';

const RootStyle = styled(Box)(() => ({
  display: 'flex',
  flexDirection: 'column',
  minHeight: '100vh',
}));

const MainStyle = styled('main')(({ theme }) => ({
  flexGrow: 1,
  marginBottom: 'auto',
  [theme.breakpoints.up('lg')]: {
    transition: theme.transitions.create('margin-left', {
      duration: theme.transitions.duration.shorter,
    }),
  },
}));

type Props = {
  children: ReactNode;
  backgroundColor?: string;
};

export default function Layout({ children, backgroundColor }: Props) {
  const theme = useTheme();

  useEffect(() => {
    const version = localStorage.getItem('version');
    if (version !== process.env.NPM_PACKAGE_VERSION) {
      localStorage.clear();
      localStorage.setItem('version', process.env.NPM_PACKAGE_VERSION || 'v1.0.0');
    }
  }, []);

  return (
    <RootStyle>
      <Header />
      <MainStyle>{children}</MainStyle>
      <Footer backgroundColor={backgroundColor || alpha(theme.palette.primary.light, 0.1)} />
      <GoogleAnalytics />
    </RootStyle>
  );
}
