import { ReactElement, ReactNode, useEffect } from 'react';
// next
import { NextPage } from 'next';
import Head from 'next/head';
import { AppProps } from 'next/app';
import { loadIntercom } from 'next-intercom';
import ThemeProvider from 'src/theme';
import MotionLazyContainer from 'src/components/animate/MotionLazyContainer';
import 'regenerator-runtime/runtime';
// notistack
import NotistackProvider from '../components/NotistackProvider';

// ----------------------------------------------------------------------

type NextPageWithLayout = NextPage & {
  getLayout?: (page: ReactElement) => ReactNode;
};

interface MyAppProps extends AppProps {
  Component: NextPageWithLayout;
}

export default function MyApp(props: MyAppProps) {
  const { Component, pageProps } = props;

  const getLayout = Component.getLayout ?? ((page) => page);

  // Load Intercom
  useEffect(() => {
    loadIntercom({
      appId: process.env.INTERCOM_APP_ID,
      ssr: false,
      initWindow: true,
      delay: 0,
    });
  }, []);

  return (
    <>
      <Head>
        <meta name="viewport" content="initial-scale=1, width=device-width" />
      </Head>

      <ThemeProvider>
        <NotistackProvider>
          <MotionLazyContainer>{getLayout(<Component {...pageProps} />)}</MotionLazyContainer>
        </NotistackProvider>
      </ThemeProvider>
    </>
  );
}
