import axios, { AxiosRequestConfig } from 'axios';
import { NextApiRequest, NextApiResponse } from 'next';

/**
 * Grading handler
 *
 * @param {NextApiRequest} req - Next.js request object
 * @param {NextApiResponse} res - Next.js response object
 */
const handleGrade = async (req: NextApiRequest, res: NextApiResponse) => {
  const { method } = req;

  switch (method) {
    /**
     * Get the result from LCAT API
     *
     * @body {string} base64_audio: current audio file in base64 string format
     * @body {string} audio_format: format of the audio file
     * @body {string} text: text to be transcribed
     *
     * @response {object}: response format from LCAT API.
     */
    case 'POST':
      const { base64_audio, audio_format, text, accent } = req.body;

      await axios
        .request({
          method: 'POST',
          url: `${process.env.PRONUNCIATION_API_URL}/${accent.toLowerCase()}`,
          headers: {
            'Content-Type': 'application/json',
            'api-key': process.env.PRONUNCIATION_API_KEY,
            'lc-beta-features': 'true',
          },
          data: `{"audio_base64":"${base64_audio}","audio_format":"${audio_format}","expected_text":"${text}"}`,
        } as AxiosRequestConfig)
        .then((response) => {
          res.status(200).json({
            ...response.data,
          });
        })
        .catch((error) => {
          const errorMsg = error?.response?.data?.detail?.[0]?.msg;
          console.error(error);
          console.error(error?.response);
          console.error(error?.response?.data);
          console.error(error?.response?.data?.detail);
          res.status(500).json({ message: errorMsg || 'Something went wrong' });
        });
      break;

    default:
      res.setHeader('Allow', ['POST']);
      res.status(405).end(`Method ${method} Not Allowed`);
      break;
  }
};

export default handleGrade;

export const config = {
  api: {
    bodyParser: {
      sizeLimit: '100mb',
    },
  },
};
