import { useRouter } from 'next/router';
// @mui
import { styled } from '@mui/material/styles';
// components
import Page from '../components/Page';
import Layout from '../layouts';
import { Stack, Typography } from '@mui/material';
// config
import products from '../utils/products.json';
import customers from '../utils/customers.json';
// components
import FeatureCard from '../components/FeatureCard';
// types
import { Products } from 'src/@types/products';
import useResponsive from 'src/hooks/useResponsive';
import ApiPricingCard from 'src/components/ApiPricingCard';

const RootStyle = styled('div')(() => ({
  paddingBlock: 60,
  height: '100%',
}));

const SubtitleStyle = styled(Typography)(({ theme }) => ({
  fontSize: '20px',
  fontWeight: '500',
  lineHeight: '30px',
  textAlign: 'center',
  color: theme.palette.primary.main,
}));

const TitleStyle = styled(Typography)(() => ({
  fontSize: '28px',
  fontWeight: '700',
  lineHeight: '42px',
  textAlign: 'center',
}));

const FeatureStackStyle = styled(Stack)(() => ({
  alignItems: 'center',
  justifyContent: 'center',
  padding: '20px 10px',
  width: 'clamp(max(300px, min(600px, 100%)), 90%, 900px)',
  marginInline: 'auto',
  gap: '24px',
}));

const CardStackStyle = styled('div')(() => ({
  gap: '24px',
  marginTop: '55px',
  width: '100%',
  justifyContent: 'center',
  display: 'grid',
  gridTemplateColumns: 'repeat(auto-fill, minmax(300px, 1fr))',
}));

HomePage.getLayout = function getLayout(page: React.ReactElement) {
  return <Layout backgroundColor="white">{page}</Layout>;
};

export default function HomePage() {
  const { push } = useRouter();
  const isMobile = useResponsive('down', 'sm');

  return (
    <Page title="Experience Products">
      <RootStyle>
        <FeatureStackStyle>
          <SubtitleStyle>Language Confidence product demo</SubtitleStyle>
          <TitleStyle>
            Explore our API capabilities and use cases through an interactive demo
          </TitleStyle>
          <CardStackStyle>
            {Object.entries(products as Products).map(([key, feature]) => (
              <FeatureCard
                key={key}
                title={feature.title}
                description={feature.description}
                image={feature.image}
                handleClick={() => push(`/${key}`)}
                tag={feature?.tag}
              />
            ))}
          </CardStackStyle>
          <ApiPricingCard />
          {customers.map((customer, index) => (
            <FeatureCard
              horizontal={!isMobile}
              key={index}
              title={customer.title}
              description={customer.description}
              image={customer.image}
              handleClick={() => window.open(customer.link, '_blank', 'noopener noreferrer')}
              buttonText="Explore now"
              aspectRatio=""
            />
          ))}
        </FeatureStackStyle>
      </RootStyle>
    </Page>
  );
}
