import { useRouter } from 'next/router';
import useResponsive from '../hooks/useResponsive';
// @mui
import { styled, alpha } from '@mui/material/styles';
// components
import Page from '../components/Page';
import Layout from '../layouts';
// config
import products from '../utils/products.json';
// components
import FeatureCard from '../components/FeatureCard';
import Breadcrumb from '../components/Breadcrumb';
// types
import { GetStaticProps } from 'next';
import { Products } from 'src/@types/products';
import { Box } from '@mui/material';
import ApiPricingCard from 'src/components/ApiPricingCard';

export const RootStyle = styled('div')(({ theme }) => ({
  minHeight: 'calc(100vh - 130px)',
  backgroundColor: alpha(theme.palette.primary.light, 0.1),
  paddingBlock: '45px 60px',
  [theme.breakpoints.up('md')]: {
    height: 'max-content',
  },
}));

const containerStyle = {
  width: 'clamp(max(300px, min(600px, 100%)), 90%, 1200px)',
  marginInline: 'auto',
};

export const ContainerStyle = styled('div', {
  shouldForwardProp: (prop) => prop !== 'isDesktop',
})<any>(({ isDesktop }) => ({
  ...containerStyle,
  gap: '16px',
  display: 'grid',
  gridTemplateColumns: 'repeat(auto-fill, minmax(400px, 1fr))',
}));

HomePage.getLayout = function getLayout(page: React.ReactElement) {
  return <Layout>{page}</Layout>;
};

export default function HomePage({ products }: { products: Products }) {
  const { push } = useRouter();
  const isDesktop = useResponsive('up', 'lg');

  const handleClick = (key: string) => {
    const previousTest = window.localStorage.getItem(`scripted-${key}-test`);
    if (previousTest && parseInt(previousTest) > 0) {
      const previousChosenAccent = window.localStorage.getItem(`${key}-accent`);
      if (previousChosenAccent) push(`/scripted/${key}/` + JSON.parse(previousChosenAccent));
    } else {
      push(`/scripted/${key}`);
    }
  };

  return (
    <Page title="Scripted Speech Assessment">
      {Breadcrumb([
        { title: 'External Demo', location: '/', disabled: false },
        { title: 'Scripted Speech Assessment', location: '/scripted', disabled: false },
      ])}
      <RootStyle>
        <ContainerStyle isDesktop={isDesktop}>
          {Object.entries(products.scripted.levels).map(([key, level]) => (
            <FeatureCard
              horizontal={true}
              key={key}
              title={level.title}
              description={level.description}
              image={level.image}
              handleClick={() => handleClick(key)}
            />
          ))}
        </ContainerStyle>

        <Box sx={containerStyle} mt={10}>
          <ApiPricingCard />
        </Box>
      </RootStyle>
    </Page>
  );
}

export const getStaticProps: GetStaticProps<{
  products: Products;
}> = async () => ({
  props: {
    products,
  },
});
