import { useRouter } from 'next/router';
// components
import Page from '../../components/Page';
import Layout from '../../layouts';
import Breadcrumb from '../../components/Breadcrumb';
import AccentCard from 'src/components/AccentCard';
// types
import { GetStaticProps, GetStaticPaths } from 'next';
import { Products } from '../../@types/products';
// config
import products from '../../utils/products.json';
// @mui
import { styled } from '@mui/material/styles';
import { Box, Typography } from '@mui/material';
import ApiPricingCard from 'src/components/ApiPricingCard';

const containerStyle = {
  width: 'clamp(max(300px, min(600px, 95%)), 80%, 890px)',
  marginInline: 'auto',
};

const RootStyle = styled('div')(({ theme }) => ({
  minHeight: 'calc(100vh - 130px)',
  paddingBlock: '45px 60px',
  [theme.breakpoints.up('md')]: {
    height: 'max-content',
  },
  '& .container': {
    '& .cardContainer': {
      display: 'flex',
      justifyContent: 'center',
    },
  },
}));

const SubtitleStyle = styled(Typography)(({ theme }) => ({
  fontSize: '20px',
  fontWeight: '500',
  lineHeight: '30px',
  textAlign: 'center',
  color: theme.palette.primary.main,
}));

const TitleStyle = styled(Typography)(() => ({
  fontSize: '28px',
  fontWeight: '700',
  lineHeight: '42px',
  textAlign: 'center',
}));

TryPage.getLayout = function getLayout(page: React.ReactElement) {
  return <Layout>{page}</Layout>;
};

export default function TryPage({ products }: { products: Products }) {
  const { query } = useRouter();
  const { push } = useRouter();
  const { level } = query;
  if (!products) return null;
  const levelData = products.scripted.levels[level as string];

  return (
    <Page title={`Language Confidence ${level}`}>
      {Breadcrumb([
        { title: 'External Demo', location: '/', disabled: false },
        { title: 'Scripted Speech Assessment', location: '/scripted', disabled: false },
        { title: levelData.title, location: `/scripted/${level}`, disabled: false },
      ])}
      <RootStyle>
        <Box className="container">
          <SubtitleStyle>Pick your accent</SubtitleStyle>
          <TitleStyle>Select which accent you want to compare yourself against</TitleStyle>
          <Box className="cardContainer">
            <AccentCard
              horizontal={false}
              key={'US'}
              title={'US Accent'}
              image={'/images/US.svg'}
              handleClick={() => push(`/scripted/${level}/us`)}
            />
            <AccentCard
              horizontal={false}
              key={'UK'}
              title={'UK Accent'}
              image={'/images/UK.svg'}
              handleClick={() => push(`/scripted/${level}/uk`)}
            />
          </Box>

          <Box sx={containerStyle} mt={8}>
            <ApiPricingCard />
          </Box>
        </Box>
      </RootStyle>
    </Page>
  );
}

export const getStaticPaths: GetStaticPaths = async () => ({
  paths: Object.keys(products.scripted.levels).map((level) => ({
    params: { level },
  })),
  fallback: false,
});

export const getStaticProps: GetStaticProps<{
  products: Products;
}> = async () => ({
  props: {
    products,
  },
});
