import { useRouter } from 'next/router';
import useResponsive from '../hooks/useResponsive';
// components
import Page from '../components/Page';
import Layout from '../layouts';
import FeatureCard from '../components/FeatureCard';
import Breadcrumb from '../components/Breadcrumb';
import { RootStyle, ContainerStyle } from './scripted';
// config
import products from '../utils/products.json';
import ApiPricingCard from 'src/components/ApiPricingCard';
import { Box } from '@mui/material';

const containerStyle = {
  width: 'clamp(max(300px, min(600px, 100%)), 90%, 1200px)',
  marginInline: 'auto',
};

HomePage.getLayout = function getLayout(page: React.ReactElement) {
  return <Layout>{page}</Layout>;
};

export default function HomePage() {
  const { push } = useRouter();
  const isDesktop = useResponsive('up', 'lg');

  const handleClick = (key: string) => {
    push(`/unscripted/${key}`);
  };

  return (
    <Page title="Unscripted Speech Assessment">
      {Breadcrumb([
        { title: 'External Demo', location: '/', disabled: false },
        { title: 'Unscripted Speech Assessment', location: '/unscripted', disabled: false },
      ])}
      <RootStyle>
        <ContainerStyle isDesktop={isDesktop}>
          {Object.entries(products.unscripted.levels).map(([key, level]) => (
            <FeatureCard
              horizontal={true}
              key={key}
              title={level.title}
              description={level.description}
              image={level.image}
              handleClick={() => handleClick(key)}
            />
          ))}
        </ContainerStyle>

        <Box sx={containerStyle} mt={10}>
          <ApiPricingCard />
        </Box>
      </RootStyle>
    </Page>
  );
}
