import difflib from 'difflib';

export function compareTexts(givenText: string, expectedText: string) {
  const givenWords = givenText.split(/\s+/).flatMap((word) => word.split(/\W/).filter(Boolean));
  const givenWordsLower = givenWords.map((word) => word.toLowerCase());
  const expectedWords = expectedText
    .split(/\s+/)
    .flatMap((word) => word.split(/\W/).filter(Boolean));
  const expectedWordsLower = expectedWords.map((word) => word.toLowerCase());
  const sm = new difflib.SequenceMatcher(null, givenWordsLower, expectedWordsLower);
  const opcodes = sm.getOpcodes();
  const mistakes: Array<{
    word: string;
    correct: boolean;
    substitutedWith: string | null;
  }> = [];

  opcodes.forEach(([tag, i1, i2, j1, j2]) => {
    if (tag === 'replace' || tag === 'delete') {
      //word is the student answer, substitutedWith is replacement of wrong answer
      mistakes.push({
        word:
          tag === 'replace'
            ? expectedWords.slice(j1, j2).join(' ')
            : givenWords.slice(i1, i2).join(' '),
        correct: false,
        substitutedWith: tag === 'replace' ? givenWords.slice(i1, i2).join(' ') : '',
      });
    } else if (tag === 'insert') {
      for (let j = j1; j < j2; j++) {
        mistakes.push({
          word: expectedWords[j],
          correct: false,
          substitutedWith: null,
        });
      }
    } else if (tag === 'equal') {
      for (let i = i1; i < i2; i++) {
        mistakes.push({
          word: givenWords[i],
          correct: true,
          substitutedWith: null,
        });
      }
    }
  });

  return mistakes;
}
